# pyrdmp

Python Library for Dynamic Movement Primitives with Reinforcement Learning

## Dependencies

Python package requirements can be installed via pip with: `pip install -r requirements.txt`

Additionally, you will need the python3-tk package which can be installed on ubuntu with:
`sudo apt install python3-tk`

## Running

Install the `pyrdmp` package locally with: `pip install .`

## Examples

You can run examples by navigating to `examples/` 
and running `./ex_dmp_adaptation.py` 
